@@ -103,7 +103,7 @@ QT_CHARTS_BEGIN_NAMESPACE
 
 /*!
  \class QChart
- \inmodule Qt Charts
+ \inmodule QtCharts
  \brief The QChart class manages the graphical representation of the chart's
  series, legends, and axes.
 
@@ -223,7 +223,9 @@ QT_CHARTS_BEGIN_NAMESPACE
   \property QChart::plotArea
   \brief The rectangle within which the chart is drawn.
 
-  The plot area does not include the area defined by margins.
+  The plot area does not include the area defined by margins. By default this will resize if inside
+  a QChartView. If an explicit size is set for the plot area then it will respect this, to revert
+  back to the default behavior, then calling \c{setPlotArea(QRectF());} will achieve this.
 */
 
 /*!
@@ -583,6 +585,11 @@ QRectF QChart::plotArea() const
     return d_ptr->m_presenter->geometry();
 }
 
+void QChart::setPlotArea(const QRectF &rect)
+{
+    d_ptr->m_presenter->setFixedGeometry(rect);
+}
+
 /*!
     Sets the brush used to fill the background of the plot area of the chart to \a brush.
 
